==> haskell-simple-smt-0.9.4-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-smt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-smt
version:              0.9.4
visibility:           public
id:                   simple-smt-0.9.4-Jx1HMFT1SHD9UxnOQCWyMN
key:                  simple-smt-0.9.4-Jx1HMFT1SHD9UxnOQCWyMN
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A simple way to interact with an SMT solver process.
description:          A simple way to interact with an SMT solver process.
category:             Math
abi:                  e9acdcdc488ec646525e367bad240498
exposed:              True
exposed-modules:      SimpleSMT
import-dirs:          /usr/lib/ghc-8.8.3/site-local/simple-smt-0.9.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/simple-smt-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/simple-smt-0.9.4
hs-libraries:         HSsimple-smt-0.9.4-Jx1HMFT1SHD9UxnOQCWyMN
depends:              base-4.13.0.0 process-1.6.8.0
haddock-interfaces:   /usr/share/doc/haskell-simple-smt/html/simple-smt.haddock
haddock-html:         /usr/share/doc/haskell-simple-smt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-smt-0.9.4-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-smt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-smt
version:              0.9.4
visibility:           public
id:                   simple-smt-0.9.4-5ZcL7LDDMZDDIyW3YskKHi
key:                  simple-smt-0.9.4-5ZcL7LDDMZDDIyW3YskKHi
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A simple way to interact with an SMT solver process.
description:          A simple way to interact with an SMT solver process.
category:             Math
abi:                  607d71ab0be61e6b2c86be4bb5a0344d
exposed:              True
exposed-modules:      SimpleSMT
import-dirs:          /usr/lib/ghc-8.10.1/site-local/simple-smt-0.9.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/simple-smt-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/simple-smt-0.9.4
hs-libraries:         HSsimple-smt-0.9.4-5ZcL7LDDMZDDIyW3YskKHi
depends:              base-4.14.0.0 process-1.6.8.2
haddock-interfaces:   /usr/share/doc/haskell-simple-smt/html/simple-smt.haddock
haddock-html:         /usr/share/doc/haskell-simple-smt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
